@@ -1,6 +1,7 @@
 from readchar import key
 
 from inquirer import errors
+from inquirer.render.console._other import GLOBAL_OTHER_CHOICE
 from inquirer.render.console.base import MAX_OPTIONS_DISPLAYED_AT_ONCE
 from inquirer.render.console.base import BaseConsoleRender
 from inquirer.render.console.base import half_options
@@ -47,7 +48,7 @@ class List(BaseConsoleRender):
             ):
 
                 color = self.theme.List.selection_color
-                symbol = self.theme.List.selection_cursor
+                symbol = "+" if choice == GLOBAL_OTHER_CHOICE else self.theme.List.selection_cursor
             else:
                 color = self.theme.List.unselected_color
                 symbol = " "
@@ -69,6 +70,14 @@ class List(BaseConsoleRender):
             return
         if pressed == key.ENTER:
             value = self.question.choices[self.current]
+
+            if value == GLOBAL_OTHER_CHOICE:
+                value = self.other_input()
+                if not value:
+                    # Clear the print inquirer.text made, since the user didn't enter anything
+                    print(self.terminal.move_up + self.terminal.clear_eol, end="")
+                    return
+
             raise errors.EndOfInput(getattr(value, "value", value))
 
         if pressed == key.CTRL_C:
